@@ -46,7 +46,7 @@ class OceanusClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def CopyJobs(self, request):
@@ -69,7 +69,7 @@ class OceanusClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def CreateFolder(self, request):
@@ -92,7 +92,7 @@ class OceanusClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def CreateJob(self, request):
@@ -115,7 +115,7 @@ class OceanusClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def CreateJobConfig(self, request):
@@ -138,7 +138,7 @@ class OceanusClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def CreateResource(self, request):
@@ -161,7 +161,7 @@ class OceanusClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def CreateResourceConfig(self, request):
@@ -184,7 +184,76 @@ class OceanusClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def CreateWorkSpace(self, request):
+        """创建工作空间
+
+        :param request: Request instance for CreateWorkSpace.
+        :type request: :class:`tencentcloud.oceanus.v20190422.models.CreateWorkSpaceRequest`
+        :rtype: :class:`tencentcloud.oceanus.v20190422.models.CreateWorkSpaceResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("CreateWorkSpace", params, headers=headers)
+            response = json.loads(body)
+            model = models.CreateWorkSpaceResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def DeleteFolders(self, request):
+        """作业列表删除文件夹
+
+        :param request: Request instance for DeleteFolders.
+        :type request: :class:`tencentcloud.oceanus.v20190422.models.DeleteFoldersRequest`
+        :rtype: :class:`tencentcloud.oceanus.v20190422.models.DeleteFoldersResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DeleteFolders", params, headers=headers)
+            response = json.loads(body)
+            model = models.DeleteFoldersResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def DeleteJobConfigs(self, request):
+        """删除作业配置
+
+        :param request: Request instance for DeleteJobConfigs.
+        :type request: :class:`tencentcloud.oceanus.v20190422.models.DeleteJobConfigsRequest`
+        :rtype: :class:`tencentcloud.oceanus.v20190422.models.DeleteJobConfigsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DeleteJobConfigs", params, headers=headers)
+            response = json.loads(body)
+            model = models.DeleteJobConfigsResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DeleteJobs(self, request):
@@ -207,7 +276,7 @@ class OceanusClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DeleteResourceConfigs(self, request):
@@ -230,7 +299,7 @@ class OceanusClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DeleteResources(self, request):
@@ -253,7 +322,7 @@ class OceanusClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DeleteTableConfig(self, request):
@@ -276,7 +345,30 @@ class OceanusClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def DeleteWorkSpace(self, request):
+        """删除工作空间
+
+        :param request: Request instance for DeleteWorkSpace.
+        :type request: :class:`tencentcloud.oceanus.v20190422.models.DeleteWorkSpaceRequest`
+        :rtype: :class:`tencentcloud.oceanus.v20190422.models.DeleteWorkSpaceResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DeleteWorkSpace", params, headers=headers)
+            response = json.loads(body)
+            model = models.DeleteWorkSpaceResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeClusters(self, request):
@@ -299,7 +391,30 @@ class OceanusClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def DescribeFolder(self, request):
+        """查询指定文件夹及其相应的子文件夹信息
+
+        :param request: Request instance for DescribeFolder.
+        :type request: :class:`tencentcloud.oceanus.v20190422.models.DescribeFolderRequest`
+        :rtype: :class:`tencentcloud.oceanus.v20190422.models.DescribeFolderResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeFolder", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeFolderResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeJobConfigs(self, request):
@@ -322,7 +437,7 @@ class OceanusClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeJobSavepoint(self, request):
@@ -345,7 +460,30 @@ class OceanusClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def DescribeJobSubmissionLog(self, request):
+        """查询作业实例启动日志
+
+        :param request: Request instance for DescribeJobSubmissionLog.
+        :type request: :class:`tencentcloud.oceanus.v20190422.models.DescribeJobSubmissionLogRequest`
+        :rtype: :class:`tencentcloud.oceanus.v20190422.models.DescribeJobSubmissionLogResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeJobSubmissionLog", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeJobSubmissionLogResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeJobs(self, request):
@@ -368,7 +506,7 @@ class OceanusClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeResourceConfigs(self, request):
@@ -391,7 +529,7 @@ class OceanusClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeResourceRelatedJobs(self, request):
@@ -414,7 +552,7 @@ class OceanusClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeResources(self, request):
@@ -437,7 +575,7 @@ class OceanusClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeSystemResources(self, request):
@@ -460,7 +598,7 @@ class OceanusClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeTreeJobs(self, request):
@@ -483,7 +621,7 @@ class OceanusClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def DescribeTreeResources(self, request):
@@ -506,7 +644,76 @@ class OceanusClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def DescribeWorkSpaces(self, request):
+        """授权工作空间列表
+
+        :param request: Request instance for DescribeWorkSpaces.
+        :type request: :class:`tencentcloud.oceanus.v20190422.models.DescribeWorkSpacesRequest`
+        :rtype: :class:`tencentcloud.oceanus.v20190422.models.DescribeWorkSpacesResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("DescribeWorkSpaces", params, headers=headers)
+            response = json.loads(body)
+            model = models.DescribeWorkSpacesResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def FetchSqlGatewayStatementResult(self, request):
+        """查询Sql Gateway的Statement执行结果
+
+        :param request: Request instance for FetchSqlGatewayStatementResult.
+        :type request: :class:`tencentcloud.oceanus.v20190422.models.FetchSqlGatewayStatementResultRequest`
+        :rtype: :class:`tencentcloud.oceanus.v20190422.models.FetchSqlGatewayStatementResultResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("FetchSqlGatewayStatementResult", params, headers=headers)
+            response = json.loads(body)
+            model = models.FetchSqlGatewayStatementResultResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def ModifyFolder(self, request):
+        """自定义树状结构页面拖拽文件夹
+
+        :param request: Request instance for ModifyFolder.
+        :type request: :class:`tencentcloud.oceanus.v20190422.models.ModifyFolderRequest`
+        :rtype: :class:`tencentcloud.oceanus.v20190422.models.ModifyFolderResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ModifyFolder", params, headers=headers)
+            response = json.loads(body)
+            model = models.ModifyFolderResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def ModifyJob(self, request):
@@ -520,7 +727,6 @@ class OceanusClient(AbstractClient):
         假设作业运行状态，则先停止作业，再启动作业，中间状态丢失
         假设作业暂停状态，则将作业更改为停止状态，中间状态丢失
 
-
         :param request: Request instance for ModifyJob.
         :type request: :class:`tencentcloud.oceanus.v20190422.models.ModifyJobRequest`
         :rtype: :class:`tencentcloud.oceanus.v20190422.models.ModifyJobResponse`
@@ -538,7 +744,30 @@ class OceanusClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def ModifyWorkSpace(self, request):
+        """修改工作空间
+
+        :param request: Request instance for ModifyWorkSpace.
+        :type request: :class:`tencentcloud.oceanus.v20190422.models.ModifyWorkSpaceRequest`
+        :rtype: :class:`tencentcloud.oceanus.v20190422.models.ModifyWorkSpaceResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("ModifyWorkSpace", params, headers=headers)
+            response = json.loads(body)
+            model = models.ModifyWorkSpaceResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def RunJobs(self, request):
@@ -561,7 +790,30 @@ class OceanusClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
+
+
+    def RunSqlGatewayStatement(self, request):
+        """通过Sql gateway执行satement
+
+        :param request: Request instance for RunSqlGatewayStatement.
+        :type request: :class:`tencentcloud.oceanus.v20190422.models.RunSqlGatewayStatementRequest`
+        :rtype: :class:`tencentcloud.oceanus.v20190422.models.RunSqlGatewayStatementResponse`
+
+        """
+        try:
+            params = request._serialize()
+            headers = request.headers
+            body = self.call("RunSqlGatewayStatement", params, headers=headers)
+            response = json.loads(body)
+            model = models.RunSqlGatewayStatementResponse()
+            model._deserialize(response["Response"])
+            return model
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def StopJobs(self, request):
@@ -584,7 +836,7 @@ class OceanusClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
+                raise TencentCloudSDKException(type(e).__name__, str(e))
 
 
     def TriggerJobSavepoint(self, request):
@@ -607,4 +859,4 @@ class OceanusClient(AbstractClient):
             if isinstance(e, TencentCloudSDKException):
                 raise
             else:
-                raise TencentCloudSDKException(e.message, e.message)
\ No newline at end of file
+                raise TencentCloudSDKException(type(e).__name__, str(e))
\ No newline at end of file
